@@ -1,14 +1,16 @@
 package Crypt::Random::Source::Base::File;
 # ABSTRACT: File (or device) random data sources
-$Crypt::Random::Source::Base::File::VERSION = '0.10';
-use Any::Moose;
+
+our $VERSION = '0.11';
+
+use Moo;
 
 use Carp qw(croak);
 
 extends qw(Crypt::Random::Source::Base::Handle);
 
 use IO::File;
-use namespace::autoclean;
+use namespace::clean;
 
 has path => (
     is => "rw",
@@ -40,7 +42,7 @@ Crypt::Random::Source::Base::File - File (or device) random data sources
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -67,11 +69,16 @@ A required attribute, the path to the file to open.
 
 Uses L<IO::File> to open C<path> for reading.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
